@@ -22,16 +22,6 @@ DrugSynonymsParser <- R6::R6Class(
         coder = xmlGetAttr(rec,
                            name = "coder")
       )
-    },
-    save_db_table = function(parsed_tbl) {
-      if (private$save_table) {
-        save_drug_sub(
-          con = private$database_connection,
-          df = parsed_tbl,
-          table_name = "drug_syn",
-          field_types = list(synonym = "varchar(534)")
-        )
-      }
     }
   )
 )
@@ -40,34 +30,16 @@ DrugSynonymsParser <- R6::R6Class(
 #'
 #' Other names or identifiers that are associated with this drug.
 #'
-#' @inheritSection run_all_parsers read_drugbank_xml_db
-#' @inheritParams run_all_parsers
-#'
 #' @return  a tibble with 3 variables:
 #' \describe{
 #'  \item{language}{Names of the drug in languages other than English.}
-#'  \item{coder}{Organisation or source providing the synonym. For example,
+#'  \item{coder}{Organization or source providing the synonym. For example,
 #'   INN indicates the synonym is an International Nonproprietary Name,
 #'   while IUPAC indicates the synonym is the nomenclature designated by the
 #'   International Union of Pure and Applied Chemistry.}
 #'  \item{\emph{drugbank_id}}{drugbank id}
 #' }
-#' @family drugs
-#'
-#' @inherit run_all_parsers examples
-#' @export
-drug_syn <-
-  function(save_table = FALSE,
-           save_csv = FALSE,
-           csv_path = ".",
-           override_csv = FALSE,
-           database_connection = NULL) {
-    DrugSynonymsParser$new(
-      save_table,
-      save_csv,
-      csv_path,
-      override_csv,
-      database_connection,
-      "drug_syn",
-    )$parse()
-  }
+#' @keywords internal
+drug_syn <- function() {
+    DrugSynonymsParser$new("drug_syn")$parse()
+}
